pub struct Union(/* private fields */);Expand description
Implementations
Sourceimpl Union
impl Union
Sourcepub fn try_new(
union: impl IntoIterator<Item = (impl TryInto<Name, Error = impl Into<Box<dyn Error>>>, impl TryInto<LogicalStreamType, Error = impl Into<Box<dyn Error>>>)>,
) -> Result<Self>
pub fn try_new( union: impl IntoIterator<Item = (impl TryInto<Name, Error = impl Into<Box<dyn Error>>>, impl TryInto<LogicalStreamType, Error = impl Into<Box<dyn Error>>>)>, ) -> Result<Self>
Returns a new Union logical stream type. Returns an error when either the name or logical stream type conversion fails, or when there are duplicate names.
Sourcepub fn tag(&self) -> Option<(String, BitCount)>
pub fn tag(&self) -> Option<(String, BitCount)>
Returns the tag name and width of this union. Reference
Sourcepub fn iter(&self) -> impl Iterator<Item = (&Name, &LogicalStreamType)>
pub fn iter(&self) -> impl Iterator<Item = (&Name, &LogicalStreamType)>
Returns an iterator over the fields of the Union.